@@ -263,7 +263,7 @@ class CurrencyConverter(HTMLRequestHandler):
         return None
 
 
-class CurrencyConverterAPI(CurrencyConverter, APIRequestHandler):
+class CurrencyConverterAPI(APIRequestHandler, CurrencyConverter):
     """Request handler for the currency converter JSON API."""
 
     async def get(self, *, head: bool = False) -> None:
