@@ -234,11 +234,7 @@ def get_all_handlers(
         (r"/.well-known/(.*)", StaticFileHandler, {"path": ".well-known"})
     )
 
-    logger.debug(
-        "Loaded %d handlers: %s",
-        len(handlers),
-        "; ".join(str(handler) for handler in handlers),
-    )
+    logger.debug("Loaded %d handlers.", len(handlers))
 
     return handlers
 
@@ -344,6 +340,10 @@ def setup_logging(
     )
 
     root_logger = logging.getLogger()
+
+    if root_logger.handlers:
+        return
+
     root_logger.setLevel(logging.DEBUG if debug else logging.INFO)
 
     stream_handler = logging.StreamHandler()
