@@ -179,7 +179,9 @@ class BaseRequestHandler(RequestHandler):
         self.set_header("Referrer-Policy", "same-origin")
         # dev.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/SharedArrayBuffer
         self.set_header("Cross-Origin-Opener-Policy", "same-origin")
-        if self.request.path != "/kaenguru-comics":  # TODO: make this better
+        if self.request.path == "/kaenguru-comics":  # TODO: make this better
+            self.set_header("Cross-Origin-Embedder-Policy", "credentialless")
+        else:
             self.set_header("Cross-Origin-Embedder-Policy", "require-corp")
         if self.settings.get("HSTS"):
             # dev.mozilla.org/docs/Web/HTTP/Headers/Strict-Transport-Security
